| Title: | SWD principles applied to svyby objects with robust coordinate scaling and big numbers. |
|---|---|
| Description: | SWD principles applied to svyby objects with robust coordinate scaling and big numbers. |
| Authors: | Alfonso Cano |
| Maintainer: | Alfonso Cano <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.0 |
| Built: | 2026-06-04 09:53:01 UTC |
| Source: | https://github.com/AlfCano/rk.storytelling.survey |